
Spectrum Analysis
=============

.. automodapi:: grizli.utils
    :no-inheritance-diagram:
    :skip: OrderedDict

.. automodapi:: grizli.grismconf
    :no-inheritance-diagram:

.. automodapi:: grizli.model
    :no-inheritance-diagram:
    :skip: Table, OrderedDict
    
.. automodapi:: grizli.multifit
    :no-inheritance-diagram:
    :skip: Table, OrderedDict
   
